ContactEmail class

Represents an email address

Annotations

Constructors

ContactEmail({required String address, EmailLabel label = EmailLabel.home, String customLabel = '', bool isPrimary = false})
Creates a ContactEmail with the given parameters
const
ContactEmail.fromJson(Map<String, dynamic> json)
Creates an email from a JSON map
factory

Properties

address String
The email address
final
customLabel String
Custom label text when label is EmailLabel.custom
final
displayLabel String
Returns the display label for this email
no setter
hashCode int
The hash code for this object.
no setterinherited
isPrimary bool
Whether this is the primary email address
final
isValid bool
Returns true if the email address has a valid format
no setter
label EmailLabel
The label type for this email
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({String? address, EmailLabel? label, String? customLabel, bool? isPrimary}) ContactEmail
Creates a copy of this email with the given fields replaced with new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this email to a JSON map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited