ContactOrganization class

Represents an organization/job information

Annotations

Constructors

ContactOrganization({String company = '', String title = '', String department = ''})
Creates a new ContactOrganization with optional company, title, and department
const
ContactOrganization.fromJson(Map<String, dynamic> json)
Creates an organization from a JSON map
factory

Properties

company String
The company name
final
department String
The department
final
formattedInfo String
Returns the formatted organization info
no setter
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Returns true if at least one field is not empty
no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title String
The job title
final

Methods

copyWith({String? company, String? title, String? department}) ContactOrganization
Creates a copy of this organization with given fields replaced with new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this organization to a JSON map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited