ContactsException class

Custom exceptions for the contacts bridge

Implemented types
Implementers

Constructors

ContactsException(String message, [String? code])
Creates a ContactsException with a message and optional error code
const

Properties

code String?
Optional error code for programmatic handling
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited