EmailLabel enum

Enum for different email labels

Inheritance
Available extensions

Values

home → const EmailLabel

Home email

work → const EmailLabel

Work email

school → const EmailLabel

School email

other → const EmailLabel

Other email

custom → const EmailLabel

Custom email with custom label

iCloud → const EmailLabel

iCloud email

mobile → const EmailLabel

Mobile email

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EmailLabel>
A constant List of the values in this enum, in order of their declaration.