EventLabel enum

Enum for different event labels

Inheritance
Available extensions

Values

birthday → const EventLabel

Birthday event

anniversary → const EventLabel

Anniversary event

other → const EventLabel

Other type of event

custom → const EventLabel

Custom label event

workAnniversary → const EventLabel

Work anniversary event (iOS/macOS specific)

newborn → const EventLabel

Newborn event (Android specific)

kids → const EventLabel

Kids event (Android specific)

parentAnniversary → const EventLabel

Parent anniversary event (Android specific)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EventLabel>
A constant List of the values in this enum, in order of their declaration.