InvalidContactException class

Exception thrown when contact data is invalid or corrupted

Inheritance

Constructors

InvalidContactException(String message, [String? code])
Creates an InvalidContactException with a message and optional error code
const

Properties

code String?
Optional error code for programmatic handling
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited