PermissionException class

Exception thrown when permission is denied or insufficient

Inheritance

Constructors

PermissionException(String message, [String? code])
Creates a PermissionException with a message and optional error code
const

Properties

code String?
Optional error code for programmatic handling
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited