PhoneLabel enum

Enum for different phone number labels

Inheritance
Available extensions

Values

mobile → const PhoneLabel

Mobile phone number

home → const PhoneLabel

Home phone number

work → const PhoneLabel

Work phone number

main → const PhoneLabel

Main phone number

homeFax → const PhoneLabel

Home fax number

workFax → const PhoneLabel

Work fax number

pager → const PhoneLabel

Pager number

other → const PhoneLabel

Other type of phone number

custom → const PhoneLabel

Custom label phone number

iPhone → const PhoneLabel

iPhone number (iOS specific)

assistant → const PhoneLabel

Assistant phone number (Android specific)

callback → const PhoneLabel

Callback phone number (Android specific)

car → const PhoneLabel

Car phone number (Android specific)

companyMain → const PhoneLabel

Company main phone number (Android specific)

isdn → const PhoneLabel

ISDN phone number (Android specific)

radio → const PhoneLabel

Radio phone number (Android specific)

telex → const PhoneLabel

Telex phone number (Android specific)

ttyTdd → const PhoneLabel

TTY TDD phone number (Android specific)

workMobile → const PhoneLabel

Work mobile phone number (Android specific)

workPager → const PhoneLabel

Work pager phone number (Android specific)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PhoneLabel>
A constant List of the values in this enum, in order of their declaration.