ContactName class
Represents a name with all its components
- Annotations
Constructors
- ContactName({String first = '', String last = '', String middle = '', String prefix = '', String suffix = '', String nickname = '', String phoneticFirst = '', String phoneticLast = '', String phoneticMiddle = ''})
-
Creates a ContactName with the given parameters
const
-
ContactName.fromJson(Map<
String, dynamic> json) -
Creates a contact name from a JSON map
factory
Properties
- displayName → String
-
Returns the full display name
no setter
- first → String
-
The first name
final
- formalName → String
-
Returns the formal name (Last, First Middle)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- last → String
-
The last name
final
- middle → String
-
The middle name
final
- nickname → String
-
The nickname
final
- phoneticFirst → String
-
The phonetic first name
final
- phoneticLast → String
-
The phonetic last name
final
- phoneticMiddle → String
-
The phonetic middle name
final
- prefix → String
-
The name prefix (Mr., Dr., etc.)
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - suffix → String
-
The name suffix (Jr., Sr., etc.)
final
Methods
-
copyWith(
{String? first, String? last, String? middle, String? prefix, String? suffix, String? nickname, String? phoneticFirst, String? phoneticLast, String? phoneticMiddle}) → ContactName - Creates a copy of this contact name with the given fields replaced with new values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this contact name to a JSON map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited