ContactNotFoundException class
Exception thrown when a requested contact is not found
- Inheritance
-
- Object
- ContactsException
- ContactNotFoundException
Constructors
- ContactNotFoundException(String message, [String? code])
-
Creates a ContactNotFoundException with a message and optional error code
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited