ResultExtensions<T> extension
Extension methods for easier result handling
- on
-
- Result<
T>
- Result<
Methods
-
unwrap(
) → T -
Available on Result<
Returns the value if successful, throws the failure message otherwiseT> , provided by the ResultExtensions extension -
unwrapOr(
T defaultValue) → T -
Available on Result<
Returns the value if successful, the provided default value otherwiseT> , provided by the ResultExtensions extension -
unwrapOrElse(
T defaultValue(Failure)) → T -
Available on Result<
Returns the value if successful, the result of the provided function otherwiseT> , provided by the ResultExtensions extension